;============================================================================
;This Program was designed to test various areas of Paradox under the
;Windows environment and to specifically compare these results to
;Paradox For Windows running on the Same Machine
;
;Tests
;1. Create NNNN Records - Unindexed
;2. Create NNNN Records - Indexed
;3. Add Data From Indexed Table To Unindexed Table
;4. Add Data From Unindexed Table To Indexed Table
;5. Sort Unindexed Table In Descending Order
;6. Scan Add Unindexed Table To Indexed Table with Locate
;7. Query Insert Indexed Table Into Unindexed Table
;8. Query Insert Unindexed Table Into Indexed Table
;9. Query Change All Record in the Unindexed Table to A Single Value
;
;Machine
;
;  386DX40 - 10Mb Available Memory to Paradox
;          - 2Mb Smartdrive Cache
;          - 2Mb Ram Drive
;          - 200Mb Quantam Hard Disk (90Mb Available)
;
;Results
;
;
;============================================================================


PROC Benchdriver.u()

   MESSAGE "Creating Data Files"
   CREATE "Indexed"
   "Key"          :  "a10*" ,
   "KeyCnt"       :  "N" ,
   "KeyName"      :  "a50"

   CREATE "UnIndex"
   "Key"          :  "a10" ,
   "KeyCnt"       :  "N"   ,
   "KeyName"      :  "a50"

   Number.Of.Records = 50 ; Total Number Of Records To Evaluate

   CLEAR
   @10,10 ?? "Enter Number Of Records To Process "
   ACCEPT "N" DEFAULT Number.of.records TO Number.of.Records
   IF NOT RETVAL THEN
      QUIT
   ENDIF
   CURSOR OFF
   CLEAR
   test1.u()
   test2.u()
   test3.u()
   test4.u()
   test5.u()
   test6.u()
   test7.u()
   test8.u()
   test9.u()


   BEEP
   WriteResults.u()
ENDPROC

PROC Test1.u()
   Stime = Ticks()
   @1,0 ?? "Test 1 - Creating " + Strval(Number.of.Records)+ " Indexed Records"
   COEDIT "Indexed"
   FOR i FROM 1 TO Number.of.records
      MESSAGE "Record " ,i," of ", Number.of.Records," Records"
      INS
      [Key] = strval(i)
      [KeyCnt] = i
      [KeyName] = "Record Number " + strval(i)
   ENDFOR
   DO_IT!
   CLEARALL
   Etime = ticks()
   Etime1 = (Etime-stime)/60000
   Recs1 = Number.Of.Records
   Message""
ENDPROC

PROC Test2.u()
   Stime = Ticks()
   @2,0 ?? "Test 2 - Creating " + Strval(Number.of.Records)+ " Unindexed Records"
   COEDIT "Unindex"
   FOR i FROM 1 TO Number.of.records
      MESSAGE "Record " ,i," of ", Number.of.Records," Records"
      INS
      [Key] = strval(i)
      [KeyCnt] = i
      [KeyName] = "Record Number " + strval(i)
   ENDFOR
   DO_IT!
   CLEARALL
   Etime = ticks()
   Etime2 = (Etime-stime)/60000
   Recs2 = Number.Of.Records
   Message""
ENDPROC

PROC Test3.u()
   @3,0 ?? "Test 3 - Adding Data from Indexed Table To Unindexed Table"
   EMPTY "Unindex"
   Stime = Ticks()
   ADD "Indexed" "Unindex"
   Etime = ticks()
   Etime3 = (Etime-stime)/60000
   Recs3 = Number.Of.Records
   Message""
   CLEARALL
ENDPROC

PROC Test4.u()
   @4,0 ?? "Test 4 - Adding Data from UnIndexed Table To Indexed Table"
   EMPTY "indexed"
   Stime = Ticks()
   ADD "Unindex" "Indexed"
   Etime = ticks()
   Etime4 = (Etime-stime)/60000
   Recs4 = Number.Of.Records
   Message""
   CLEARALL
ENDPROC

PROC Test5.u()
   @5,0 ?? "Test 5 - Sort Unindexed Table"
   Stime = Ticks()
   SORT "Unindex" ON "KeyCnt" D
   Etime = ticks()
   Etime5 = (Etime-stime)/60000
   Recs5 = Number.Of.Records
   Message""
   CLEARALL
ENDPROC

PROC Test6.u()
   Stime = Ticks()
   @6,0 ?? "Test 6 - Scan Add Record From Unindexed Table To Indexed Table"
   VIEW "Indexed"
   COEDIT "Unindex"
   cnt = nrecords(table())
   SCAN
      MESSAGE "Record " ,recno()," of ", cnt," Records"
      COPYTOARRAY a
      MOVETO [Indexed->Key]
      LOCATE a["Key"]
      IF NOT RETVAL THEN
         INS
         [Key] = a["Key"]
      ENDIF
      [KeyCnt] = a["Keycnt"]
      [KeyName] ="Located "+[Key]
      MOVETO "Unindex"
   ENDSCAN
   DO_IT!
   CLEARALL
   Etime = ticks()
   Etime6 = (Etime-stime)/60000
   Recs6 = Number.Of.Records
   Message""
ENDPROC

PROC Test7.u()
   EMPTY "UnIndex"
   Stime = Ticks()
   @7,0 ?? "Test 7 - Query Insert From Indexed Table To Unindexed Table"
   {Ask} SELECT "Indexed"
   [Key] = "_a"
   [KeyCnt] = "_b"
   [KeyName] = "_c"

   {Ask} SELECT "Unindex"
   "INSERT"
   [Key] = "_a"
   [KeyCnt] = "_b"
   [KeyName] = "_c"

   DO_IT!
   CLEARALL
   Etime = ticks()
   Etime7 = (Etime-stime)/60000
   Recs7 = Number.Of.Records
   Message""
ENDPROC

PROC Test8.u()
   EMPTY "Indexed"
   Stime = Ticks()
   @8,0 ?? "Test 8 - Query Insert From UnIndexed Table To Indexed Table"
   {Ask} SELECT "UnIndex"
   [Key] = "_a"
   [KeyCnt] = "_b"
   [KeyName] = "_c"

   {Ask} SELECT "Indexed"
   "INSERT"
   [Key] = "_a"
   [KeyCnt] = "_b"
   [KeyName] = "_c"

   DO_IT!
   CLEARALL
   Etime = ticks()
   Etime8 = (Etime-stime)/60000
   Recs8 = Number.Of.Records
   Message""
ENDPROC

PROC Test9.u()
   EMPTY "Indexed"
   Stime = Ticks()
   @9,0 ?? "Test 9 - Query Change All Records In UnIndexed Table"

   {Ask} SELECT "Unindex"
   [KeyName] = "Changeto Changed"

   DO_IT!
   CLEARALL
   Etime = ticks()
   Etime9 = (Etime-stime)/60000
   Recs9 = Number.Of.Records
   Message""
ENDPROC

PROC WriteResults.u()
   MESSAGE "Writing Results"
   COEDIT "Bench"
   MOVETO [Test]
   LOCATE 1 ; Test 1
   [Elapsed Time DOS] = Etime1
   [Records Processed] = Recs1
   LOCATE 2 ; Test 2
   [Elapsed Time DOS] = Etime2
   [Records Processed] = Recs2
   LOCATE 3 ; Test 3
   [Elapsed Time DOS] = Etime3
   [Records Processed] = Recs3
   LOCATE 4 ; Test 4
   [Elapsed Time DOS] = Etime4
   [Records Processed] = Recs4
   LOCATE 5 ; Test 5
   [Elapsed Time DOS] = Etime5
   [Records Processed] = Recs5
   LOCATE 6 ; Test 6
   [Elapsed Time DOS] = Etime6
   [Records Processed] = Recs6
   LOCATE 7 ; Test 7
   [Elapsed Time DOS] = Etime7
   [Records Processed] = Recs7
   LOCATE 8 ; Test 8
   [Elapsed Time DOS] = Etime8
   [Records Processed] = Recs8
   LOCATE 9 ; Test 9
   [Elapsed Time DOS] = Etime9
   [Records Processed] = Recs9

   DO_IT!
ENDPROC
;=====================================================================

RELEASE VARS ALL
Benchdriver.u()






